@@ -2,7 +2,7 @@ package Solution::Block;
 {
     use strict;
     use warnings;
-    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -1; our $VERSION = sprintf('%1.3f%03d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $MAJOR, $MINOR, abs $DEV);
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -1; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     use lib '../../lib';
     use Solution::Error;
     our @ISA = qw[Solution::Document];
@@ -29,28 +29,32 @@ package Solution::Block;
                           parent     => $args->{'parent'},
         }, $class;
         $self->{'conditions'} = (
-            $args->{'tag_name'} eq 'else'
-            ? [1]
+            $args->{'tag_name'} eq 'else' ?
+                [1]
             : sub {    # Oh, what a mess...
-                my @conditions = split m[\s+\b(and|or)\b\s+],
-                    (defined $args->{'attrs'} ? $args->{'attrs'} : '');
+                my @conditions
+                    = split m[\s+\b(and|or)\b\s+],
+                    $args->{parent}->{tag_name} eq 'for' ?
+                    1
+                    : (defined $args->{'attrs'} ? $args->{'attrs'} : '');
                 my @equality;
                 while (my $x = shift @conditions) {
                     push @equality, (
                         $x =~ m[\b(?:and|or)\b]    # XXX - ARG
-                        ? bless({template  => $args->{'template'},
-                                 parent    => $self,
-                                 condition => $x,
-                                 lvalue    => pop @equality,
-                                 rvalue =>
-                                     Solution::Condition->new(
+                        ?
+                            bless({template  => $args->{'template'},
+                                   parent    => $self,
+                                   condition => $x,
+                                   lvalue    => pop @equality,
+                                   rvalue =>
+                                       Solution::Condition->new(
                                           {template => $args->{'template'},
                                            parent   => $self,
                                            attrs    => shift @conditions
                                           }
-                                     )
-                                },
-                                'Solution::Condition'
+                                       )
+                                  },
+                                  'Solution::Condition'
                             )
                         : Solution::Condition->new(
                                           {attrs    => $x,
@@ -124,6 +128,6 @@ covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Block.pm 7f57e32 2010-09-19 02:51:25Z sanko@cpan.org $
+=for git $Id$
 
 =cut
