@@ -2,7 +2,7 @@ package Solution::Tag::Assign;
 {
     use strict;
     use warnings;
-    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -3; our $VERSION = sprintf('%1.3f%03d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $MAJOR, $MINOR, abs $DEV);
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -3; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     use lib '../../../lib';
     use Solution::Error;
     use Solution::Utility;
@@ -39,8 +39,8 @@ package Solution::Tag::Assign;
                 $filter =~ s[\s*$][];    # XXX - the splitter should clean...
                 $filter =~ s[^\s*][];    # XXX -  ...this up for us.
                 my @f_args
-                    = $f_args
-                    ? split $Solution::Utility::VariableFilterArgumentParser,
+                    = $f_args ?
+                    split $Solution::Utility::VariableFilterArgumentParser,
                     $f_args
                     : ();
                 push @{$args->{'filters'}}, [$filter, \@f_args];
@@ -126,6 +126,6 @@ covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Assign.pm c79b7e5 2010-09-19 04:43:55Z sanko@cpan.org $
+=for git $Id$
 
 =cut
