@@ -2,10 +2,10 @@ package Solution::Utility;
 {
     use strict;
     use warnings;
-    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -3; our $VERSION = sprintf('%1.3f%03d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $MAJOR, $MINOR, abs $DEV);
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -3; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     our $FilterSeparator = qr[\s*\|\s*];
     my $ArgumentSeparator = qr[,];
-    our $FilterArgumentSeparator    = qr[:];
+    our $FilterArgumentSeparator    = qr[\s*:\s*];
     our $VariableAttributeSeparator = qr[\.];
     our $TagStart                   = qr[{%\s*];
     our $TagEnd                     = qr[\s*%}];
@@ -14,7 +14,7 @@ package Solution::Utility;
     our $VariableStart = qr[{{\s*];
     our $VariableEnd   = qr[\s*}}];
     my $VariableIncompleteEnd = qr[}}?];
-    my $QuotedString          = qr/"[^"]+"|'[^']+'/;
+    my $QuotedString          = qr/"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'/;
     my $QuotedFragment = qr/${QuotedString}|(?:[^\s,\|'"]|${QuotedString})+/;
     my $StrictQuotedFragment = qr/"[^"]+"|'[^']+'|[^\s,\|,\:,\,]+/;
     my $FirstFilterArgument
@@ -35,8 +35,9 @@ package Solution::Utility;
                                 (?:\s*\|\s*(.+)\s*)?                 #   filters
                             ${VariableEnd}                          # }}
                             $]x;
+
     our $VariableFilterArgumentParser
-        = qr[\s*,\s*(?=(?:[^\"]*\"[^\"]*\")*(?![^\"]*\"))];
+        = qr[\s*,\s*(?=(?:[^\']*\'[^\']*\')*(?![^\']*\'))];
 
     sub tokenize {
         map { $_ ? $_ : () } split $TemplateParser, shift || '';
@@ -81,6 +82,6 @@ covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Utility.pm c79b7e5 2010-09-19 04:43:55Z sanko@cpan.org $
+=for git $Id$
 
 =cut
