@@ -3,7 +3,7 @@ package Solution::Variable;
     use strict;
     use warnings;
     use lib '../../lib';
-    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -3; our $VERSION = sprintf('%1.3f%03d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $MAJOR, $MINOR, abs $DEV);
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -4; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     use Solution::Error;
     our @ISA = qw[Solution::Document];
 
@@ -31,9 +31,6 @@ package Solution::Variable;
         my $val = $self->resolve($self->{'variable'});
     FILTER: for my $filter (@{$self->{'filters'}}) {
             my ($name, $args) = @$filter;
-
-            #use Data::Dump;
-            #ddx $val, $filter; #, $self->template->context->scope;
             map { $_ = $self->resolve($_) || $_ } @$args;
         PACKAGE: for my $package (@{$self->template->filters}) {
                 if (my $call = $package->can($name)) {
@@ -54,40 +51,45 @@ package Solution::Variable;
 
 =head1 NAME
 
-Solution::Variable - Generic container
+Solution::Variable - Generic Value Container
 
 =head1 Description
 
-This class can hold just about anything. ...and does. Internally, it's the
-basic container for everything. ...for all definitions of 'everything.'
+This class can hold just about anything. This is the class responsible for
+handling echo statements:
 
-=head1 See Also
+    Hello, {{ name }}. It's been {{ lastseen | date_relative }} since you
+    logged in.
 
-Liquid for Designers: http://wiki.github.com/tobi/liquid/liquid-for-designers
+Internally, a variable is the basic container for everything; lists, scalars,
+hashes, and even objects.
 
-L<Solution|Solution/"Create your own filters">'s docs on custom filter creation
+L<Filters|Solution::Filter> are applied to Solution::Variable during the
+render stage.
 
 =head1 Author
 
 Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
 
-The original Liquid template system was developed by jadedPixel
-(http://jadedpixel.com/) and Tobias Lütke (http://blog.leetsoft.com/).
+CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009,2010 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify it under
-the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
-this distribution or http://www.perlfoundation.org/artistic_license_2_0.  For
-clarification, see http://www.perlfoundation.org/artistic_2_0_notes.
+the terms of
+L<The Artistic License 2.0|http://www.perlfoundation.org/artistic_license_2_0>.
+See the F<LICENSE> file included with this distribution or
+L<notes on the Artistic License 2.0|http://www.perlfoundation.org/artistic_2_0_notes>
+for clarification.
 
 When separated from the distribution, all original POD documentation is
-covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
-http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
-clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
+covered by the
+L<Creative Commons Attribution-Share Alike 3.0 License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>.
+See the
+L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
 
-=for git $Id: Variable.pm c79b7e5 2010-09-19 04:43:55Z sanko@cpan.org $
+=for git $Id$
 
 =cut
